@@ -34,7 +34,7 @@ SECTION_RE = re.compile(r"---(\w+)---")
 LAYER_RE = re.compile(r"//\sLAYER\s(\d+)")
 COMBINATOR_RE = re.compile(r"^([\w.]+)#([0-9a-f]+)\s(?:.*)=\s([\w<>.]+);$", re.MULTILINE)
 ARGS_RE = re.compile(r"[^{](\w+):([\w?!.<>#]+)")
-FLAGS_RE = re.compile(r"flags(\d?).(\d+)\?")
+FLAGS_RE = re.compile(r"flags(\d?)\.(\d+)\?")
 FLAGS_RE_2 = re.compile(r"flags(\d?)\.(\d+)\?([\w<>.]+)")
 FLAGS_RE_3 = re.compile(r"flags(\d?):#")
 INT_RE = re.compile(r"int(\d+)")
@@ -115,7 +115,7 @@ def get_type_hint(type: str) -> str:
         type = f"List[{get_type_hint(sub_type)}]"
 
     if is_core:
-        return f"Union[None, {type}] = None" if is_flag else type
+        return f"Optional[{type}] = None" if is_flag else type
     else:
         ns, name = type.split(".") if "." in type else ("", type)
         type = f'"raw.base.' + ".".join([ns, name]).strip(".") + '"'
@@ -132,7 +132,7 @@ def sort_args(args):
         args.remove(i)
 
     for i in args[:]:
-        if re.match(r"flags\d?", i[0]):
+        if re.match(r"flags\d?", i[0]) and i[1] == "#":
             args.remove(i)
 
     return args + flags
@@ -361,14 +361,12 @@ def start(format: bool = False):
 
         for i, arg in enumerate(sorted_args):
             arg_name, arg_type = arg
-            is_optional = FLAGS_RE.match(arg_type)
-            flag_number = is_optional.group(1) if is_optional else -1
             arg_type = arg_type.split("?")[-1]
 
             docstring_args.append(
                 "{}{}: {}".format(
                     arg_name,
-                    " (optional)".format(flag_number) if is_optional else "",
+                    " (optional)",
                     get_docstring_arg_type(arg_type, is_pyrogram_type=c.namespace == "pyrogram")
                 )
             )
@@ -413,7 +411,8 @@ def start(format: bool = False):
                         if flag.group(3) == "true" or flag.group(3).startswith("Vector"):
                             write_flags.append(f"{arg_name} |= (1 << {flag.group(2)}) if self.{i[0]} else 0")
                         else:
-                            write_flags.append(f"{arg_name} |= (1 << {flag.group(2)}) if self.{i[0]} is not None else 0")
+                            write_flags.append(
+                                f"{arg_name} |= (1 << {flag.group(2)}) if self.{i[0]} is not None else 0")
 
                 write_flags = "\n        ".join([
                     f"{arg_name} = 0",
